@@ -8,6 +8,7 @@
 #define BOTAN_PCURVES_H_
 
 #include <botan/concepts.h>
+#include <botan/mem_ops.h>
 #include <botan/secmem.h>
 #include <botan/types.h>
 #include <array>
@@ -29,7 +30,7 @@ namespace Botan::PCurve {
 /**
 * An elliptic curve without cofactor in Weierstrass form
 */
-class PrimeOrderCurve {
+class PrimeOrderCurve /* NOLINT(*-special-member-functions) */ {
    public:
       /// Somewhat arbitrary maximum size for a field or scalar
       ///
@@ -71,6 +72,11 @@ class PrimeOrderCurve {
             Scalar& operator=(Scalar&& other) = default;
             ~Scalar() = default;
 
+            void _zeroize() {
+               secure_scrub_memory(m_value);
+               std::ranges::fill(m_value, 0);  // secure_scrub_memory does not guarantee zero output!
+            }
+
             const auto& _curve() const { return m_curve; }
 
             const auto& _value() const { return m_value; }
@@ -97,7 +103,7 @@ class PrimeOrderCurve {
             AffinePoint& operator=(AffinePoint&& other) = default;
             ~AffinePoint() = default;
 
-            static AffinePoint generator(CurvePtr curve) { return curve->generator(); }
+            static AffinePoint generator(const CurvePtr& curve) { return curve->generator(); }
 
             const auto& _curve() const { return m_curve; }
 
@@ -153,7 +159,7 @@ class PrimeOrderCurve {
             StorageUnit m_z;
       };
 
-      class PrecomputedMul2Table {
+      class PrecomputedMul2Table /* NOLINT(*-special-member-functions) */ {
          public:
             virtual ~PrecomputedMul2Table() = default;
       };
