@@ -64,7 +64,8 @@ void check_invalid_ciphertexts(Test::Result& result,
                                Botan::RandomNumberGenerator& rng) {
    const size_t tests_to_run = (Test::run_long_tests() ? 20 : 5);
 
-   size_t ciphertext_accepted = 0, ciphertext_rejected = 0;
+   size_t ciphertext_accepted = 0;
+   size_t ciphertext_rejected = 0;
 
    for(size_t i = 0; i < tests_to_run; ++i) {
       const std::vector<uint8_t> bad_ctext = Test::mutate_vec(ciphertext, rng);
@@ -331,15 +332,15 @@ std::vector<Test::Result> PK_Sign_Verify_DER_Test::run() {
    } catch(const Botan::Lookup_Error&) {
       result.test_note("Skipping sign/verify regression test");
    } catch(const std::exception& e) {
-      result.test_failure("regresstion test verification failed", e.what());
+      result.test_failure("regression test verification failed", e.what());
    }
 
    return {result};
 }
 
-std::vector<std::string> PK_Sign_Verify_DER_Test::possible_providers(const std::string& algo) {
+std::vector<std::string> PK_Sign_Verify_DER_Test::possible_providers(const std::string& algo_name) {
    std::vector<std::string> pk_provider =
-      Botan::probe_provider_private_key(algo, {"base", "commoncrypto", "openssl", "tpm"});
+      Botan::probe_provider_private_key(algo_name, {"base", "commoncrypto", "openssl", "tpm"});
    return Test::provider_filter(pk_provider);
 }
 
@@ -379,6 +380,7 @@ Test::Result PK_Encryption_Decryption_Test::run_one_test(const std::string& pad_
 
       result.test_eq(dec_provider, "decryption of KAT", decrypted, plaintext);
       check_invalid_ciphertexts(result, *decryptor, plaintext, ciphertext, this->rng());
+      decryptors.push_back(std::move(decryptor));
    }
 
    for(const auto& enc_provider : possible_providers(algo_name())) {
@@ -555,9 +557,9 @@ Test::Result PK_Key_Agreement_Test::run_one_test(const std::string& header, cons
    return result;
 }
 
-std::vector<std::string> PK_Key_Generation_Test::possible_providers(const std::string& algo) {
+std::vector<std::string> PK_Key_Generation_Test::possible_providers(const std::string& algo_name) {
    std::vector<std::string> pk_provider =
-      Botan::probe_provider_private_key(algo, {"base", "commoncrypto", "openssl", "tpm"});
+      Botan::probe_provider_private_key(algo_name, {"base", "commoncrypto", "openssl", "tpm"});
    return Test::provider_filter(pk_provider);
 }
 
@@ -607,20 +609,20 @@ std::vector<Test::Result> PK_Key_Generation_Test::run() {
    std::vector<Test::Result> results;
 
    for(const auto& param : keygen_params()) {
-      const auto algo = algo_name(param);
-      const std::string report_name = Botan::fmt("{}{}", algo, (param.empty() ? param : " " + param));
+      const auto algorithm_name = algo_name(param);
+      const std::string report_name = Botan::fmt("{}{}", algorithm_name, (param.empty() ? param : " " + param));
 
       Test::Result result(report_name + " keygen");
 
-      const std::vector<std::string> providers = possible_providers(algo);
+      const std::vector<std::string> providers = possible_providers(algorithm_name);
 
       if(providers.empty()) {
-         result.note_missing("provider key generation " + algo);
+         result.note_missing("provider key generation " + algorithm_name);
       }
 
       result.start_timer();
       for(auto&& prov : providers) {
-         auto key_p = Botan::create_private_key(algo, this->rng(), param, prov);
+         auto key_p = Botan::create_private_key(algorithm_name, this->rng(), param, prov);
 
          if(key_p == nullptr) {
             continue;
@@ -788,7 +790,7 @@ Test::Result PK_Key_Validity_Test::run_one_test(const std::string& header, const
 
    const bool tested_valid = pubkey->check_key(this->rng(), true);
 
-   result.test_eq("Expected validation result", expected_valid, tested_valid);
+   result.test_eq("Expected validation result", tested_valid, expected_valid);
 
    return result;
 }
@@ -797,7 +799,7 @@ PK_Key_Generation_Stability_Test::PK_Key_Generation_Stability_Test(const std::st
                                                                    const std::string& test_src) :
       PK_Test(algo, test_src, "Rng,RngSeed,Key", "KeyParams,RngParams") {}
 
-Test::Result PK_Key_Generation_Stability_Test::run_one_test(const std::string&, const VarMap& vars) {
+Test::Result PK_Key_Generation_Stability_Test::run_one_test(const std::string& /*header*/, const VarMap& vars) {
    const std::string key_param = vars.get_opt_str("KeyParams", "");
    const std::string rng_algo = vars.get_req_str("Rng");
    const std::string rng_params = vars.get_opt_str("RngParams", "");
@@ -906,10 +908,23 @@ class PK_API_Sign_Test : public Text_Based_Test {
                            !privkey->remaining_operations().has_value());
          }
 
-         auto signer = std::make_unique<Botan::PK_Signer>(
-            *privkey, this->rng(), sig_params, Botan::Signature_Format::Standard, provider);
-         auto verifier =
-            std::make_unique<Botan::PK_Verifier>(*pubkey, verify_params, Botan::Signature_Format::Standard, provider);
+         auto [signer, verifier] = [&] {
+            try {
+               return std::make_pair(std::make_unique<Botan::PK_Signer>(
+                                        *privkey, this->rng(), sig_params, Botan::Signature_Format::Standard, provider),
+                                     std::make_unique<Botan::PK_Verifier>(
+                                        *pubkey, verify_params, Botan::Signature_Format::Standard, provider));
+            } catch(Botan::Algorithm_Not_Found&) {}
+
+            return std::pair<std::unique_ptr<Botan::PK_Signer>, std::unique_ptr<Botan::PK_Verifier>>{};
+         }();
+
+         if(!signer || !verifier) {
+            result.test_note(Botan::fmt(
+               "Skipping Sign/verify API tests for {}({}) with provider {}", algorithm, algo_params, provider));
+            return result;
+         }
+
          result.confirm("Creating PK_Signer works", signer != nullptr);
          result.confirm("Creating PK_Signer works", verifier != nullptr);
 
@@ -931,7 +946,7 @@ class PK_API_Sign_Test : public Text_Based_Test {
          return result;
       }
 
-      bool skip_this_test([[maybe_unused]] const std::string& header, const VarMap&) override {
+      bool skip_this_test([[maybe_unused]] const std::string& header, const VarMap& /*vars*/) override {
    #if !defined(BOTAN_HAS_SLH_DSA_WITH_SHA2)
          if(header == "SLH-DSA") {
             return true;
@@ -951,7 +966,7 @@ class PK_Key_Decoding_Test : public Text_Based_Test {
       PK_Key_Decoding_Test() : Text_Based_Test("pubkey/key_encoding.vec", "Key") {}
 
    protected:
-      Test::Result run_one_test(const std::string&, const VarMap& vars) final {
+      Test::Result run_one_test(const std::string& /*header*/, const VarMap& vars) final {
          const auto key = vars.get_req_bin("Key");
 
          Test::Result result("PK Key Decoding");
